pub struct ECMultGenContext { /* private fields */ }Expand description
Context for accelerating the computation of a*G.
Implementations
Sourceimpl ECMultGenContext
impl ECMultGenContext
Sourcepub const unsafe fn new_from_raw(prec: [[AffineStorage; 16]; 64]) -> Self
pub const unsafe fn new_from_raw(prec: [[AffineStorage; 16]; 64]) -> Self
Create a new ECMultGenContext from raw values.
Safety
The function is unsafe because incorrect value of pre_g can lead to
crypto logic failure. You most likely do not want to use this function,
but ECMultGenContext::new_boxed.
Sourcepub fn inspect_raw(&self) -> &[[AffineStorage; 16]; 64]
pub fn inspect_raw(&self) -> &[[AffineStorage; 16]; 64]
Inspect ECMultGenContext values.
Sourceimpl ECMultGenContext
impl ECMultGenContext
pub fn ecmult_gen(&self, r: &mut Jacobian, gn: &Scalar)