Scalar

Struct Scalar 

pub struct Scalar(pub [u32; 8]);
A 256-bit scalar value.

Tuple Fields

0: [u32; 8]

Implementations

Source

impl Scalar

pub fn clear(&mut self)

Clear a scalar to prevent the leak of sensitive data.

pub fn set_int(&mut self, v: u32)

Set a scalar to an unsigned integer.

pub fn from_int(v: u32) -> Self

Create a scalar from an unsigned integer.

pub fn bits(&self, offset: usize, count: usize) -> u32

Access bits from a scalar. All requested bits must belong to the same 32-bit limb.

pub fn bits_var(&self, offset: usize, count: usize) -> u32

Access bits from a scalar. Not constant time.

pub fn cadd_bit(&mut self, bit: usize, flag: bool)

Conditionally add a power of two to a scalar. The result is not allowed to overflow.

pub fn set_b32(&mut self, b32: &[u8; 32]) -> Choice

Set a scalar from a big endian byte array, return whether it overflowed.

pub fn b32(&self) -> [u8; 32]

Convert a scalar to a byte array.

pub fn fill_b32(&self, bin: &mut [u8; 32])

Convert a scalar to a byte array.

pub fn is_zero(&self) -> bool

Check whether a scalar equals zero.

pub fn is_one(&self) -> bool

Check whether a scalar equals one.

pub fn is_high(&self) -> bool

Check whether a scalar is higher than the group order divided by 2.

pub fn cond_neg_assign(&mut self, flag: Choice)

Conditionally negate a number, in constant time.

Source

impl Scalar

pub fn mul_in_place(&mut self, a: &Scalar, b: &Scalar)

pub fn shr_int(&mut self, n: usize) -> u32

Shift a scalar right by some amount strictly between 0 and 16, returning the low bits that were shifted off.

pub fn sqr_in_place(&mut self, a: &Scalar)

pub fn sqr(&self) -> Scalar

pub fn inv_in_place(&mut self, x: &Scalar)

pub fn inv(&self) -> Scalar

pub fn inv_var(&self) -> Scalar

pub fn is_even(&self) -> bool